@@ -5,9 +5,9 @@ use warnings;
 
 use Config;
 
-my $cc = "$Config{ccname} -Wall -g $Config{cccdlflags} $Config{ccdlflags} $Config{lddlflags}";
+my $cc = "$Config{ccname} -Wall -g -std=gnu99 $Config{cccdlflags} $Config{ccdlflags} $Config{lddlflags}";
 
-$cc =~ s/(?<!-Wl,)-fwhole-archive/-Wl,-fwhole-archive/;
+$cc =~ s/(-Wl,)?-fwhole-archive//;
 
 sub compile {
 	my ($file, $out) = @_;
